@@ -1,5 +1,4 @@
-from __future__ import (absolute_import, division, print_function, 
-                        unicode_literals)
+from __future__ import (absolute_import, division, print_function)
 
 import numpy as np
 import numpy.ma as ma
@@ -449,8 +448,8 @@ def td(pres, qv, meta=True, units="degC"):
     Args: 
             
         pres (:class:`xarray.DataArray` or :class:`numpy.ndarray`): Full 
-            pressure (perturbation + base state pressure) in [Pa] with at least
-            three dimensions.  The rightmost dimensions are bottom_top x 
+            pressure (perturbation + base state pressure) in [hPa] with at 
+            least three dimensions.  The rightmost dimensions are bottom_top x 
             south_north x west_east.  
             
             Note:
@@ -678,21 +677,38 @@ def uvmet(u, v, lat, lon, cen_long, cone, meta=True, units="m s-1"):
 
 
 @set_smooth_metdata()
-def smooth2d(field, passes, meta=True):
+def smooth2d(field, passes, cenweight=2.0, meta=True):
     """Return the field smoothed.
     
-    This routine does not modify the original data.
+    The smoothing kernel applied is:
+    
+    .. math:: 
+                
+        \\frac{1}{4 + cenweight} * \\begin{bmatrix}
+                               0 & 1 & 0 \\\\
+                               1 & cenweight & 1 \\\\
+                               0 & 1 & 0
+                             \\end{bmatrix}
+    
+    Data values along the borders are left unchanged. This routine does not 
+    modify the original data supplied by the *field* parameter..
+    
+    If you need more general purpose multidimensional filtering tools, 
+    try the :meth:`scipy.ndimage.convolve` method.
     
     Args:
     
         field (:class:`xarray.DataArray` or :class:`numpy.ndarray`): The field
             to smooth, which must be at least two dimensions.  Missing/fill 
             values will be ignored as long as the type is either a 
-            :class:`numpy.ma.MaskedArray or a :class:`xarray.DataArray` with 
+            :class:`numpy.ma.MaskedArray` or a :class:`xarray.DataArray` with 
             a *_FillValue* attribute.
             
         passes (:obj:`int`): The number of smoothing passes.
         
+        cenweight (:obj:`float`, optional): The weight to apply to the 
+            center of the smoothing kernel. Default is 2.0.
+        
         meta (:obj:`bool`): Set to False to disable metadata and return 
             :class:`numpy.ndarray` instead of 
             :class:`xarray.DataArray`.  Default is True.
@@ -706,9 +722,13 @@ def smooth2d(field, passes, meta=True):
         be either a :class:`numpy.ndarray` or a :class:`numpy.ma.MaskedArray` 
         depending on the type for *field*.
         
+    See Also:
+    
+        :meth:`scipy.ndimage.convolve`
+        
     
     """
-    return _smooth2d(field, passes)
+    return _smooth2d(field, passes, cenweight)
 
 
 @set_cape_alg_metadata(is2d=True, copyarg="pres_hpa")
@@ -1278,7 +1298,7 @@ def dbz(pres, tkel, qv, qr, qs=None, qg=None, use_varint=False,
 
 @set_alg_metadata(2, "terrain", units="m2 s-2",
                   description="storm relative helicity")
-def srhel(u, v, height, terrain, top=3000.0, meta=True):
+def srhel(u, v, height, terrain, top=3000.0, lats=None, meta=True):
     """Return the storm relative helicity.
     
     This function calculates storm relative helicity from WRF ARW output. 
@@ -1324,6 +1344,11 @@ def srhel(u, v, height, terrain, top=3000.0, meta=True):
                 
         top (:obj:`float`):  The height of the layer below which helicity is 
             calculated (meters above ground level).
+            
+        lats (:class:`xarray.DataArray` or :class:`numpy.ndarray`, optional): 
+            Array of latitudes. This is required if any (or all) of your 
+            domain is in the southern hemisphere. If not provided, the 
+            northern hemisphere is assumed. Default is None.
 
         meta (:obj:`bool`): Set to False to disable metadata and return 
             :class:`numpy.ndarray` instead of 
@@ -1353,7 +1378,12 @@ def srhel(u, v, height, terrain, top=3000.0, meta=True):
     _v = np.ascontiguousarray(v[...,::-1,:,:])
     _height = np.ascontiguousarray(height[...,::-1,:,:])
     
-    return _srhel(_u, _v, _height, terrain, top)
+    if lats is None:
+        _lats = np.ones_like(terrain)
+    else:
+        _lats = lats
+    
+    return _srhel(_u, _v, _height, terrain, _lats, top)
 
 
 @set_alg_metadata(2, "u", refvarndims=3, units="m2 s-2",
